<?php

namespace Teknisa\DF\Modules\Saida\Factories;

use Doctrine\ORM\EntityManager;

class Dfs61000ConsultaloteFactory {
    private $entityManager;
    private $connection;

    public function __construct(EntityManager $entityManager) {
        $this->entityManager = $entityManager;
        $this->connection = $this->entityManager->getConnection();
    }

    public function alteraStatusEmail($nrlanctonf, $cdfilial, $nrorg) {
        try {
             $sql = <<<SQL
            UPDATE NOTAFISCAL SET IDEMAILNFE = 'E' WHERE NRLANCTONF = :P_NRLANCTONF
            AND CDFILIAL = :P_CDFILIAL
            AND NRORG    = :P_NRORG
SQL;

            $params = array(
                'P_NRLANCTONF' => $nrlanctonf,
                'P_CDFILIAL' => $cdfilial,
                'P_NRORG' => $nrorg
            );

            $std = $this->connection->prepare($sql);
            $std->execute($params);
            
        } catch (\Exception $e) {
            throw $e;
        }
    }
    
    public function getLote($nrseqloterps, $cdemploterps, $nrorg) {
        try {
            $sql = <<<SQL
            SELECT LOTE.CDEMPLOTERPS, LOTE.NRSEQLOTERPS, LOTE.NRINSJURIEST, 
            EMP.NMRAZSOCEMPR, LOTE.CDINSCMUNI, LOTE.CDINSCESTA, LOTE.NRPROTOCOLORPS, 
            LOTE.IDSTATUSLOTERPS, LOTE.DTENVIOLOTERPS, LOTE.NRORG, COUNT(RPS.NRRPS) AS QTDERPS 
            FROM LOTERPS LOTE INNER JOIN NUMERORPS RPS ON LOTE.CDEMPLOTERPS = RPS.CDEMPLOTERPS 
            AND LOTE.NRINSJURIEST = RPS.NRINSJURIEST AND LOTE.NRSEQLOTERPS = RPS.NRSEQLOTERPS 
            AND LOTE.NRORG = RPS.NRORG INNER JOIN EMPRESA EMP ON LOTE.CDEMPLOTERPS = EMP.CDEMPRESA 
            AND LOTE.NRORG = EMP.NRORG 
            AND LOTE.NRSEQLOTERPS   = :P_NRSEQLOTERPS
            AND LOTE.CDEMPLOTERPS   = :P_CDEMPLOTERPS
            AND LOTE.NRORG          = :P_NRORG
            GROUP BY LOTE.CDEMPLOTERPS, LOTE.NRSEQLOTERPS, LOTE.NRINSJURIEST, 
            EMP.NMRAZSOCEMPR, LOTE.CDINSCMUNI, LOTE.CDINSCESTA, LOTE.NRPROTOCOLORPS, LOTE.IDSTATUSLOTERPS, LOTE.DTENVIOLOTERPS, LOTE.NRORG
SQL;

            $params = array(
                'P_NRSEQLOTERPS' => $nrseqloterps,
                'P_CDEMPLOTERPS' => $cdemploterps,
                'P_NRORG' => $nrorg
            );

            $std = $this->connection->prepare($sql);
            $std->execute($params);
            
            return $std->fetchAll();
            
        } catch (\Exception $e) {
            throw $e;
        }
    }
    
    public function getNotaPorRps($nrrps, $nrorg, $cdempresa) {
        try {
            $sql = <<<SQL
            SELECT * FROM NOTAFISCAL N, NUMERORPS R 
                WHERE  R.NRRPS        = :NRRPS 
                   AND N.NRORG        = :NRORG
                   AND N.CDEMPRESA    = :CDEMPRESA
                   AND N.NRORG        = R.NRORG
                   AND N.NRRPS        = R.NRRPS
                   AND N.CDEMPRESA    = R.CDEMPLOTERPS
SQL;

            $params = array(
                'NRRPS' => $nrrps,
                'NRORG' => $nrorg,
                'CDEMPRESA' => $cdempresa
            );

            $std = $this->connection->prepare($sql);
            $std->execute($params);
            
            return $std->fetchAll();
            
        } catch (\Exception $e) {
            throw $e;
        }
    }
    
    public function getNotaAtualizada($params) {
        try {
             $sql = <<<SQL
            SELECT NR.NRSEQLOTERPS, NR.CDEMPLOTERPS, NR.CDVERIFNFSE, NF.NRORG, NF.CDEMPRESA , NF.CDFILIEMIT, NF.CDFILIAL, NF.NRLANCTONF,
                    NF.NRNOTAFISC, NF.DTEMISSAO, NF.CDCLIENTE, NF.IDSTATUS, NR.IDTRANSMISRPS,C.NRINSJURCLIE, C.NMRAZSOCCLIE, E.NMRAZSOCEMPR
                FROM NOTAFISCAL NF
                    JOIN NUMERORPS NR ON NF.NRRPS = NR.NRRPS
                    JOIN CLIENTE C ON C.CDCLIENTE = NF.CDCLIENTE
                    JOIN EMPRESA E ON E.NRORG = NF.NRORG AND E.CDEMPRESA = NF.CDEMPRESA
             WHERE NF.NRLANCTONF = :NRLANCTONF
             AND NR.NRINSJURIEST = :NRINSJURIEST
             AND NF.CDFILIAL = :CDFILIAL
             AND NF.NRORG = :NRORG
             AND NF.CDCLIENTE = :CDCLIENTE
SQL;
            $std = $this->connection->prepare($sql);
            $std->execute($params);
            
            return $std->fetchAll();
            
        } catch (\Exception $e) {
            throw $e;
        }
    }

}